@@ -1,7 +1,7 @@
-from .model import WeightedMetapath2Vec
+from .model import WeightedMetapath2VecModel
 
 
-__all__ = ['WeightedMetapath2Vec']
+__all__ = ['WeightedMetapath2VecModel']
 
 # manual versioning is DEPRECATED, use importlib.metadata to read the package version
 # __version__ = '0.1.3'
